# Copyright (c) Facebook, Inc. and its affiliates.
#
# This source code is licensed under the MIT license found in the
# LICENSE file in the root directory of this source tree.
#

from submitit.core.submission import submitit_main

if __name__ == "__main__":
    # This script is called by Executor.submit
    submitit_main()
